(function () {
    'use strict';

    var theme = 'light';

    function restoreTheme() {

        var lastTheme = getCookie('theme');

        if (!lastTheme) return;

        if (lastTheme == theme) return;

        var elements = document.querySelectorAll('input[type="radio"][name="theme"]');

        for (var i = 0; i < elements.length; i++) {
            if (elements[i].value == lastTheme) {
                elements[i].checked = true;
                changeTheme(lastTheme);
                break;
            }
        }
    }

    function addListeners() {

        var elements = document.querySelectorAll('input[type="radio"][name="theme"]');

        for (var i = 0; i < elements.length; i++) {
            elements[i].addEventListener('change', onChangeTheme);
        }
    }

    function onChangeTheme(event) {

        var value = event.target.value;

        event.stopPropagation();

        changeTheme(value);
    }

    function changeTheme(value) {

        if (!value)
            return;

        setCookie('theme', value, 1000 * 36000);

        setTheme();
    }

    function setTheme() {

        if (getCookie('theme') == 'dark')
            document.body.classList.add('odatadb-dark');
        else
            document.body.classList.remove('odatadb-dark');
    }

    function getCookie(name) {

        var matches = document.cookie.match(new RegExp('(?:^|; )' + name.replace(/([\.$?*|{}\(\)\[\]\\\/\+^])/g, '\\$1') + '=([^;]*)'));

        return matches ? decodeURIComponent(matches[1]) : undefined;
    }

    function setCookie(name, value, seconds) {

        if (seconds) {
            var date = new Date();
            date.setTime(date.getTime() + (seconds * 1000));
            var expires = '; expires=' + date.toGMTString();
        }
        else {
            var expires = '';
        }

        var samesite = ';SameSite=None; Secure';                // o.4.5 Cookie SameSite

        document.cookie = name + '=' + value + expires + samesite + '; path=/';
    }

    restoreTheme();
    addListeners();

}());
